@@ -156,7 +156,7 @@ end
 class P2PACK
   def initialize(lm,km,jm,im,r)
     @lm,@km,@jm,@im,@r = lm,km,jm,im,r
-    @itj,@tj,@iti,@ti = ISPACK::c2init(@jm,@im)
+    @itj,@tj,@iti,@ti = ISPACK::p2init(@jm,@im)
   end
 
   attr_accessor :lm, :km, :jm, :im, :r
@@ -183,6 +183,11 @@ class P2PACK
     _alloc_wg((@jm*@im*3))
     ISPACK::p2ajbs(@lm,@km,@jm,@im,@r,z,@ws,@wg,@itj,@tj,@iti,@ti).reshape!(@lm*2+1,@km*2+1)
   end
+  def ajcb(sa,sb)
+    _alloc_ws(((2*@km+1)*(2*@lm+1)))
+    _alloc_wg((@jm*@im*3))
+    ISPACK::p2ajcb(@lm,@km,@jm,@im,sa,sb,@ws,@wg,@itj,@tj,@iti,@ti).reshape!(@lm*2+1,@km*2+1)
+  end
   def g2sa(g)
     _alloc_w((@jm*@im))
     ISPACK::p2g2sa(@lm,@km,@jm,@im,g,@w,@itj,@tj,@iti,@ti).reshape!(@lm*2+1,@km*2+1)
