@@ -26,10 +26,8 @@ modulename = "ISPACK" # RubyץǻȤ⥸塼̾
 srcpath = "/home/rmizuta/install/ispack-0.71" # ISPACKΥǥ쥯ȥ
 
 cwrapper = true # Cåѡ񤭽Ф
-rubywrapper = false # Ruby̥åѡ()񤭽Ф
+rubywrapper = false # Ruby̥åѡǤ񤭽Ф(ޤʲϤΤ)
 
-#filename = "ispack/stpack.tex"
-#filename = "ispack/ndpack.tex"
 filenames = [
 #  srcpath+"/appack/doc/appack.tex", 
 #  srcpath+"/bspack/doc/bspack.tex", # ʸ̤б
@@ -626,7 +624,7 @@ file.close
 
 end # if(cwrapper) # Cåѡ񤭽Ф
 #-----------------------------------------------------------------------------#
-if(rubywrapper) # Ruby̥åѡ񤭽Ф
+if(rubywrapper) # Ruby̥åѡǤ񤭽Ф(ޤʲϤΤ)
 
 file = File.open(rbfilename,"w")
 
